@@ -16,9 +16,7 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with pygal. If not, see <http://www.gnu.org/licenses/>.
-__version__ = '0.9.17'
-from collections import namedtuple
-
+__version__ = '0.9.18'
 from pygal.graph.bar import Bar
 from pygal.graph.horizontal import HorizontalBar
 from pygal.graph.stackedbar import StackedBar
@@ -29,3 +27,8 @@ from pygal.graph.xy import XY
 from pygal.graph.pie import Pie
 from pygal.graph.radar import Radar
 from pygal.config import Config
+
+"""List of all chart types"""
+CHARTS = [
+    Bar, HorizontalBar, StackedBar, HorizontalStackedBar,
+    Line, StackedLine, XY, Pie, Radar]
